==> haskell-tasty-smallcheck-0.8.2-625-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-CFYXOhRQtHY1kvB6IblCf0
key:                  tasty-smallcheck-0.8.2-CFYXOhRQtHY1kvB6IblCf0
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  9ffa2645f156fc320a8e82bf0c747433
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-smallcheck-0.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-smallcheck-0.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-smallcheck-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-smallcheck
hs-libraries:         HStasty-smallcheck-0.8.2-CFYXOhRQtHY1kvB6IblCf0
depends:
    base-4.17.2.1 optparse-applicative-0.18.1.0-29G0KrZmXGlCO4Dj0BpI8D
    smallcheck-1.2.1.1-7V8G5ZnIziwHgokt8e3JSA
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-11mreCLIFkT6SEYpuD2Lhs

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-smallcheck-0.8.2-626-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-Kdh6UGa54Up11oEAApgkqT
key:                  tasty-smallcheck-0.8.2-Kdh6UGa54Up11oEAApgkqT
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  cf8d3b8be78ceae1b6e43179d88df99a
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-smallcheck-0.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-smallcheck-0.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-smallcheck-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-smallcheck
hs-libraries:         HStasty-smallcheck-0.8.2-Kdh6UGa54Up11oEAApgkqT
depends:
    base-4.17.2.1 optparse-applicative-0.18.1.0-29G0KrZmXGlCO4Dj0BpI8D
    smallcheck-1.2.1.1-6Vn4UptK16REVHHt4hvnwQ
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-11mreCLIFkT6SEYpuD2Lhs

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
